==> installer-framework-opensource-src-4.1.0.zip: installer-framework-opensource-src-4.1.0/src/libs/installer/copyfiletask.h <==
/**************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Installer Framework.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
**************************************************************************/

#ifndef COPYFILETASK_H
#define COPYFILETASK_H

#include "abstractfiletask.h"

namespace QInstaller {

class INSTALLER_EXPORT CopyFileTask : public AbstractFileTask
{
    Q_OBJECT
    Q_DISABLE_COPY(CopyFileTask)

public:
    CopyFileTask() {}
    explicit CopyFileTask(const FileTaskItem &item);

    explicit CopyFileTask(const QString &source);
    CopyFileTask(const QString &source, const QString &target);

    void doTask(QFutureInterface<FileTaskResult> &fi);
};

}   // namespace QInstaller

#endif // COPYFILETASK_H

==> installer-framework-opensource-src-4.4.0.zip: installer-framework-opensource-src-4.4/src/libs/installer/copyfiletask.h <==
/**************************************************************************
**
** Copyright (C) 2022 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Installer Framework.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
**************************************************************************/

#ifndef COPYFILETASK_H
#define COPYFILETASK_H

#include "abstractfiletask.h"

namespace QInstaller {

class INSTALLER_EXPORT CopyFileTask : public AbstractFileTask
{
    Q_OBJECT
    Q_DISABLE_COPY(CopyFileTask)

public:
    CopyFileTask() {}
    explicit CopyFileTask(const FileTaskItem &item);

    explicit CopyFileTask(const QString &source);
    CopyFileTask(const QString &source, const QString &target);

    void doTask(QFutureInterface<FileTaskResult> &fi) override;
};

}   // namespace QInstaller

#endif // COPYFILETASK_H
